@@ -65,8 +65,8 @@ PlotMenu <- function(x) {
 }
 
 PlotMultipleSeries <- function(mTheta, iK, iT, vDates) {
-    if (iK <= 5) {
-        layout(matrix(1:iK, iK, 1), heights = c(rep(2, iK - 1), 2.5))
+    if (iK <= 5L) {
+        layout(matrix(1:iK, iK, 1L), heights = c(rep(2, iK - 1), 2.5))
         for (i in 1:(iK)) {
             if (i == 1)
                 par(mar = c(0, 4, 0.1, 2))
@@ -88,13 +88,13 @@ PlotMultipleSeries <- function(mTheta, iK, iT, vDates) {
             axis.Date(1, at = seq(min(vDates), max(vDates), DiffTime * iT/20))
             axis.Date(1, at = seq(min(vDates), max(vDates), DiffTime * iT/5), labels = FALSE, tcl = -0.2)
         } else {
-            foo = vDates[c(1, seq(0, iT, ceiling((iT)/20))[-1])]
+            foo = vDates[c(1L, seq(0L, iT, ceiling((iT)/20))[-1])]
             axis(1, at = foo, labels = foo)
         }
     } else {
         nPlot = ceiling(iK/10)
         plotSeq = seq(1, iK + 1, 5)
-        Start = 1
+        Start = 1L
         PlotType2 = ""
 
         for (j in 1:nPlot) {
@@ -118,23 +118,23 @@ PlotMultipleSeries <- function(mTheta, iK, iT, vDates) {
 
                     grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
                     lines(vDates, mTheta[, i])
-                    axis(4, at = mean(vLim), labels = colnames(mTheta)[i], tick = F, padj = -1)
+                    axis(4L, at = mean(vLim), labels = colnames(mTheta)[i], tick = F, padj = -1)
 
-                    if (any(i == plotSeq - 1) | (i == iK)) {
+                    if (any(i == plotSeq - 1L) | (i == iK)) {
 
                       if (!is(vDates, "integer")) {
-                        axis.Date(1, at = seq(min(vDates), max(vDates), "year"))
-                        axis.Date(1, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE,
+                        axis.Date(1L, at = seq(min(vDates), max(vDates), "year"))
+                        axis.Date(1L, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE,
                           tcl = -0.2)
                       } else {
                         foo = vDates[c(1, seq(0, iT, ceiling((iT)/20))[-1])]
-                        axis(1, at = foo, labels = foo)
+                        axis(1L, at = foo, labels = foo)
                       }
 
                     }
                   }
                 }
-                Start = Start + 10
+                Start = Start + 10L
                 if (j < nPlot)
                   PlotType2 = readline("Print enter for next figures or 0 to exit\n:")
 
@@ -150,16 +150,16 @@ PlotMultipleSeries_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os, vDat
     iS = nrow(mTheta_is)
 
     if (is.numeric(vDates_is))
-        vDates_os = (length(vDates_is) + 1):(length(vDates_is) + iH)
+        vDates_os = (length(vDates_is) + 1L):(length(vDates_is) + iH)
 
     vDateFull = c(vDates_is, vDates_os)
 
-    if (iK <= 5) {
-        layout(matrix(1:iK, iK, 1), heights = c(rep(2, iK - 1), 2.5))
+    if (iK <= 5L) {
+        layout(matrix(1:iK, iK, 1L), heights = c(rep(2, iK - 1), 2.5))
         for (i in 1:(iK)) {
-            if (i == 1)
+            if (i == 1L)
                 par(mar = c(0, 4, 0.1, 2))
-            if (i != 1 & i != iK)
+            if (i != 1L & i != iK)
                 par(mar = c(0, 4, 0, 2))
             if (i == iK)
                 par(mar = c(3, 4, 0, 2))
@@ -167,18 +167,18 @@ PlotMultipleSeries_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os, vDat
             vLim = c(min(mTheta_os[, i], mTheta_is[, i]), max(mTheta_os[, i], mTheta_is[, i]))
 
             plot(vDateFull, rep(0, length(vDateFull)), type = "n", xaxt = "n", xlab = "", ylab = "",
-                las = 1, ylim = vLim)
+                las = 1L, ylim = vLim)
             grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
 
             lines(vDates_is, mTheta_is[, i])
             lines(vDates_os, mTheta_os[, i], col = "red")
 
-            abline(v = tail(vDates_is, 1), lty = 2)
-            axis(4, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = F, padj = -1)
+            abline(v = tail(vDates_is, 1L), lty = 2L)
+            axis(4L, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = FALSE, padj = -1)
         }
         if (!is(vDateFull, "integer")) {
-            axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2] - vDateFull[1]))
-            axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2] - vDateFull[1])),
+            axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2L] - vDateFull[1L]))
+            axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2L] - vDateFull[1L])),
                 labels = FALSE, tcl = -0.2)
         } else {
             foo = vDateFull[c(1, seq(0, iS + iH, ceiling((iS + iH)/20))[-1])]
@@ -186,20 +186,20 @@ PlotMultipleSeries_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os, vDat
         }
     } else {
         nPlot = ceiling(iK/10)
-        plotSeq = seq(1, iK + 1, 5)
-        Start = 1
+        plotSeq = seq(1L, iK + 1L, 5)
+        Start = 1L
         PlotType2 = ""
 
         for (j in 1:nPlot) {
             if (PlotType2 != "0") {
 
-                layout(matrix(1:10, 5, 2), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
+                layout(matrix(1:10, 5L, 2L), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
 
-                for (i in Start:(Start + 9)) {
+                for (i in Start:(Start + 9L)) {
                   if (i <= iK) {
                     if (any(i == plotSeq))
                       par(mar = c(0, 4, 0.1, 2))
-                    if (all(i != plotSeq) & all(i != plotSeq - 1))
+                    if (all(i != plotSeq) & all(i != plotSeq - 1L))
                       par(mar = c(0, 4, 0, 2))
                     if (any(i == plotSeq - 1))
                       par(mar = c(3, 4, 0, 2))
@@ -207,30 +207,30 @@ PlotMultipleSeries_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os, vDat
                     vLim = c(min(mTheta_os[, i], mTheta_is[, i]), max(mTheta_os[, i], mTheta_is[, i]))
 
                     plot(vDateFull, rep(0, length(vDateFull)), type = "n", xaxt = "n", xlab = "", ylab = "",
-                      las = 1, ylim = vLim)
+                      las = 1L, ylim = vLim)
                     grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
 
                     lines(vDates_is, mTheta_is[, i])
                     lines(vDates_os, mTheta_os[, i], col = "red")
 
-                    abline(v = tail(vDates_is, 1), lty = 2)
-                    axis(4, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = F, padj = -1)
+                    abline(v = tail(vDates_is, 1L), lty = 2L)
+                    axis(4L, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = FALSE, padj = -1)
 
-                    if (any(i == plotSeq - 1) | (i == iK)) {
+                    if (any(i == plotSeq - 1L) | (i == iK)) {
 
                       if (!is(vDateFull, "integer")) {
-                        axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2] - vDateFull[1]))
-                        axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2] -
-                          vDateFull[1])), labels = FALSE, tcl = -0.2)
+                        axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2L] - vDateFull[1L]))
+                        axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2L] -
+                          vDateFull[1L])), labels = FALSE, tcl = -0.2)
                       } else {
                         foo = vDateFull[c(1, seq(0, (iS + iH), ceiling((iS + iH)/20))[-1])]
-                        axis(1, at = foo, labels = foo)
+                        axis(1L, at = foo, labels = foo)
                       }
 
                     }
                   }
                 }
-                Start = Start + 10
+                Start = Start + 10L
                 if (j < nPlot)
                   PlotType2 = readline("Print enter for next figures or 0 to exit\n:")
 
@@ -245,20 +245,20 @@ PlotSingleSeries <- function(vTheta, iT, vDates) {
 
     vLim = c(min(vTheta), max(vTheta))
 
-    layout(matrix(1, 1, 1))
+    layout(matrix(1, 1L, 1L))
     par(mar = c(3, 4, 1, 2))
 
-    plot(vDates, vTheta, type = "n", xaxt = "n", xlab = "", ylab = "", las = 1, ylim = vLim)
+    plot(vDates, vTheta, type = "n", xaxt = "n", xlab = "", ylab = "", las = 1L, ylim = vLim)
     grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
     lines(vDates, vTheta)
-    axis(4, at = mean(vLim), labels = "vY", tick = F, padj = -1, las = 1)
+    axis(4L, at = mean(vLim), labels = "vY", tick = FALSE, padj = -1, las = 1L)
 
     if (!is(vDates, "integer")) {
-        axis.Date(1, at = seq(min(vDates), max(vDates), "year"))
-        axis.Date(1, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE, tcl = -0.2)
+        axis.Date(1L, at = seq(min(vDates), max(vDates), "year"))
+        axis.Date(1L, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE, tcl = -0.2)
     } else {
         foo = vDates[c(1, seq(0, iT, ceiling((iT)/20))[-1])]
-        axis(1, at = foo, labels = foo)
+        axis(1L, at = foo, labels = foo)
     }
 
 }
@@ -272,22 +272,22 @@ PlotForecastVsRealized_Univ <- function(mRealVsForecast, vDates_os, object) {
 
     iH = length(vDates_os)
 
-    plot(vDates_os, mRealVsForecast[, 1], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1, ylim = vLim)
+    plot(vDates_os, mRealVsForecast[, 1L], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1, ylim = vLim)
     grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
-    lines(vDates_os, mRealVsForecast[, 2])
-    lines(vDates_os, mRealVsForecast[, 1], col = "red")
+    lines(vDates_os, mRealVsForecast[, 2L])
+    lines(vDates_os, mRealVsForecast[, 1L], col = "red")
 
     if (is(object, "uGASFor") | is(object, "uGASRoll")) {
-        legend("topright", legend = c("Realized", "Predicted"), col = c("black", "red"), lty = c(1,
-            1))
+        legend("topright", legend = c("Realized", "Predicted"), col = c("black", "red"), lty = c(1L,
+            1L))
     }
     if (is(object, "uGASFit")) {
-        legend("topright", legend = c("Realized", "Filtered"), col = c("black", "red"), lty = c(1, 1))
+        legend("topright", legend = c("Realized", "Filtered"), col = c("black", "red"), lty = c(1L, 1L))
     }
 
     if (!is(vDates_os, "integer")) {
-        axis.Date(1, at = seq(min(vDates_os), max(vDates_os), vDates_os[2] - vDates_os[1]))
-        axis.Date(1, at = seq(min(vDates_os), max(vDates_os), 0.25 * (vDates_os[2] - vDates_os[1])),
+        axis.Date(1L, at = seq(min(vDates_os), max(vDates_os), vDates_os[2L] - vDates_os[1L]))
+        axis.Date(1L, at = seq(min(vDates_os), max(vDates_os), 0.25 * (vDates_os[2L] - vDates_os[1L])),
             labels = FALSE, tcl = -0.2)
     } else {
         foo = vDates_os[c(1, seq(0, iH, ceiling((iH)/20))[-1])]
@@ -299,39 +299,39 @@ PlotForecastVsRealized_Multi <- function(mReal, mForcasted, iN, vDates_os, objec
 
     iH = nrow(mForcasted)
 
-    if (iN <= 5) {
-        layout(matrix(1:iN, iN, 1), heights = c(rep(2, iN - 1), 2.5))
+    if (iN <= 5L) {
+        layout(matrix(1:iN, iN, 1L), heights = c(rep(2, iN - 1), 2.5))
 
         for (i in 1:(iN)) {
-            if (i == 1)
+            if (i == 1L)
                 par(mar = c(0, 4, 0.1, 2))
-            if (i != 1 & i != iN)
+            if (i != 1L & i != iN)
                 par(mar = c(0, 4, 0, 2))
             if (i == iN)
                 par(mar = c(3, 4, 0, 2))
 
             vLim = c(min(mReal[, i], mForcasted[, i]), max(mReal[, i], mForcasted[, i]))
 
-            plot(vDates_os, mReal[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1, ylim = vLim)
+            plot(vDates_os, mReal[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1L, ylim = vLim)
 
             grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
             lines(vDates_os, mReal[, i])
             lines(vDates_os, mForcasted[, i], col = "red")
 
-            axis(4, at = mean(vLim), labels = colnames(mReal)[i], tick = F, padj = -1)
+            axis(4L, at = mean(vLim), labels = colnames(mReal)[i], tick = F, padj = -1)
 
-            if (i == 1) {
+            if (i == 1L) {
                 if (is(object, "mGASFor") | is(object, "mGASRoll"))
-                  legend("topright", legend = c("Realized", "Predicted"), col = c("black", "red"), lty = c(1,
-                    1))
+                  legend("topright", legend = c("Realized", "Predicted"), col = c("black", "red"), lty = c(1L,
+                    1L))
                 if (is(object, "mGASFit"))
-                  legend("topright", legend = c("Realized", "Filtered"), col = c("black", "red"), lty = c(1,
-                    1))
+                  legend("topright", legend = c("Realized", "Filtered"), col = c("black", "red"), lty = c(1L,
+                    1L))
             }
         }
         if (!is(vDates_os, "integer")) {
-            axis.Date(1, at = seq(min(vDates_os), max(vDates_os), "year"))
-            axis.Date(1, at = seq(min(vDates_os), max(vDates_os), "quarter"), labels = FALSE, tcl = -0.2)
+            axis.Date(1L, at = seq(min(vDates_os), max(vDates_os), "year"))
+            axis.Date(1L, at = seq(min(vDates_os), max(vDates_os), "quarter"), labels = FALSE, tcl = -0.2)
         } else {
             foo = vDates_os[c(1, seq(0, iH, ceiling((iH)/20))[-1])]
             axis(1, at = foo, labels = foo)
@@ -340,52 +340,52 @@ PlotForecastVsRealized_Multi <- function(mReal, mForcasted, iN, vDates_os, objec
 
         nPlot = ceiling(iN/10)
         plotSeq = seq(1, iN + 1, 5)
-        Start = 1
+        Start = 1L
         PlotType2 = ""
 
         for (j in 1:nPlot) {
             if (PlotType2 != "0") {
 
-                layout(matrix(1:10, 5, 2), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
-                for (i in Start:(Start + 9)) {
+                layout(matrix(1:10, 5L, 2L), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
+                for (i in Start:(Start + 9L)) {
                   if (i <= iN) {
                     if (any(i == plotSeq))
                       par(mar = c(0, 4, 0.1, 2))
-                    if (all(i != plotSeq) & all(i != plotSeq - 1))
+                    if (all(i != plotSeq) & all(i != plotSeq - 1L))
                       par(mar = c(0, 4, 0, 2))
                     if (any(i == plotSeq - 1))
                       par(mar = c(3, 4, 0, 2))
 
                     vLim = c(min(mReal[, i], mForcasted[, i]), max(mReal[, i], mForcasted[, i]))
 
-                    plot(vDates_os, mReal[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1,
+                    plot(vDates_os, mReal[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1L,
                       ylim = vLim)
 
                     grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
                     lines(vDates_os, mReal[, i], col = "black")
                     lines(vDates_os, mForcasted[, i], col = "red")
 
-                    axis(4, at = mean(vLim), labels = colnames(mReal)[i], tick = F, padj = -1)
+                    axis(4L, at = mean(vLim), labels = colnames(mReal)[i], tick = FALSE, padj = -1)
 
                     if (any(i == plotSeq)) {
                       if (is(object, "mGASFor") | is(object, "mGASRoll"))
                         legend("topright", legend = c("Realized", "Predicted"), col = c("black", "red"),
-                          lty = c(1, 1))
+                          lty = c(1L, 1L))
                       if (is(object, "mGASFit"))
                         legend("topright", legend = c("Realized", "Filtered"), col = c("black", "red"),
-                          lty = c(1, 1))
+                          lty = c(1L, 1L))
                     }
                   }
                 }
                 if (!is(vDates_os, "integer")) {
-                  axis.Date(1, at = seq(min(vDates_os), max(vDates_os), "year"))
-                  axis.Date(1, at = seq(min(vDates_os), max(vDates_os), "quarter"), labels = FALSE,
+                  axis.Date(1L, at = seq(min(vDates_os), max(vDates_os), "year"))
+                  axis.Date(1L, at = seq(min(vDates_os), max(vDates_os), "quarter"), labels = FALSE,
                     tcl = -0.2)
                 } else {
-                  foo = vDates_os[c(1, seq(0, iH, ceiling((iH)/20))[-1])]
-                  axis(1, at = foo, labels = foo)
+                  foo = vDates_os[c(1L, seq(0L, iH, ceiling((iH)/20))[-1])]
+                  axis(1L, at = foo, labels = foo)
                 }
-                Start = Start + 10
+                Start = Start + 10L
                 if (j < nPlot)
                   PlotType2 = readline("Print enter for next figures or 0 to exit\n:")
 
@@ -395,13 +395,13 @@ PlotForecastVsRealized_Multi <- function(mReal, mForcasted, iN, vDates_os, objec
 }
 
 PlotMultipleSeries_Bands <- function(mTheta, iK, iT, vDates, cBands) {
-    iQ = dim(cBands)[2]
-    if (iK <= 5) {
-        layout(matrix(1:iK, iK, 1), heights = c(rep(2, iK - 1), 2.5))
+    iQ = dim(cBands)[2L]
+    if (iK <= 5L) {
+        layout(matrix(1:iK, iK, 1L), heights = c(rep(2, iK - 1), 2.5))
         for (i in 1:(iK)) {
-            if (i == 1)
+            if (i == 1L)
                 par(mar = c(0, 4, 0.1, 2))
-            if (i != 1 & i != iK)
+            if (i != 1L & i != iK)
                 par(mar = c(0, 4, 0, 2))
             if (i == iK)
                 par(mar = c(3, 4, 0, 2))
@@ -409,7 +409,7 @@ PlotMultipleSeries_Bands <- function(mTheta, iK, iT, vDates, cBands) {
 
             vLim = c(min(cBands[, , i]), max(cBands[, , i]))
 
-            plot(vDates, mTheta[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1, ylim = vLim)
+            plot(vDates, mTheta[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1L, ylim = vLim)
             grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
 
             lines(vDates, mTheta[, i], col = "red")
@@ -417,27 +417,27 @@ PlotMultipleSeries_Bands <- function(mTheta, iK, iT, vDates, cBands) {
               lines(vDates, cBands[, q, i], col = "blue")
             }
 
-            axis(4, at = mean(vLim), labels = colnames(mTheta)[i], tick = F, padj = -1)
+            axis(4L, at = mean(vLim), labels = colnames(mTheta)[i], tick = FALSE, padj = -1)
         }
         if (!is(vDates, "integer")) {
-            axis.Date(1, at = seq(min(vDates), max(vDates), "year"))
-            axis.Date(1, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE, tcl = -0.2)
+            axis.Date(1L, at = seq(min(vDates), max(vDates), "year"))
+            axis.Date(1L, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE, tcl = -0.2)
         } else {
-            foo = vDates[c(1, seq(0, iT, ceiling((iT)/20))[-1])]
-            axis(1, at = foo, labels = foo)
+            foo = vDates[c(1L, seq(0L, iT, ceiling((iT)/20))[-1])]
+            axis(1L, at = foo, labels = foo)
         }
     } else {
         nPlot = ceiling(iK/10)
-        plotSeq = seq(1, iK + 1, 5)
-        Start = 1
+        plotSeq = seq(1L, iK + 1, 5)
+        Start = 1L
         PlotType2 = ""
 
         for (j in 1:nPlot) {
             if (PlotType2 != "0") {
 
-                layout(matrix(1:10, 5, 2), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
+                layout(matrix(1:10, 5L, 2L), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
 
-                for (i in Start:(Start + 9)) {
+                for (i in Start:(Start + 9L)) {
                   if (i <= iK) {
                     if (any(i == plotSeq))
                       par(mar = c(0, 4, 0.1, 2))
@@ -448,7 +448,7 @@ PlotMultipleSeries_Bands <- function(mTheta, iK, iT, vDates, cBands) {
 
                     vLim = c(min(cBands[, , i]), max(cBands[, , i]))
 
-                    plot(vDates, mTheta[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1,
+                    plot(vDates, mTheta[, i], type = "n", xaxt = "n", xlab = "", ylab = "", las = 1L,
                       ylim = vLim)
 
                     grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
@@ -456,23 +456,23 @@ PlotMultipleSeries_Bands <- function(mTheta, iK, iT, vDates, cBands) {
                     for (q in 1:iQ) {
                       lines(vDates, cBands[, q, i], col = "red")
                     }
-                    axis(4, at = mean(vLim), labels = colnames(mTheta)[i], tick = F, padj = -1)
+                    axis(4L, at = mean(vLim), labels = colnames(mTheta)[i], tick = F, padj = -1)
 
-                    if (any(i == plotSeq - 1) | (i == iK)) {
+                    if (any(i == plotSeq - 1L) | (i == iK)) {
 
                       if (!is(vDates, "integer")) {
-                        axis.Date(1, at = seq(min(vDates), max(vDates), "year"))
-                        axis.Date(1, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE,
+                        axis.Date(1L, at = seq(min(vDates), max(vDates), "year"))
+                        axis.Date(1L, at = seq(min(vDates), max(vDates), "quarter"), labels = FALSE,
                           tcl = -0.2)
                       } else {
                         foo = vDates[c(1, seq(0, iT, ceiling((iT)/20))[-1])]
-                        axis(1, at = foo, labels = foo)
+                        axis(1L, at = foo, labels = foo)
                       }
 
                     }
                   }
                 }
-                Start = Start + 10
+                Start = Start + 10L
                 if (j < nPlot)
                   PlotType2 = readline("Print enter for next figures or 0 to exit\n:")
 
@@ -484,30 +484,30 @@ PlotMultipleSeries_Bands <- function(mTheta, iK, iT, vDates, cBands) {
 }
 
 PlotMultipleSeries_Bands_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os, vDates_is, cBands) {
-    iQ = dim(cBands)[2]
+    iQ = dim(cBands)[2L]
 
     iS = nrow(mTheta_is)
 
     if (is.numeric(vDates_is)) {
-        vDates_os = (length(vDates_is) + 1):(length(vDates_is) + iH)
+        vDates_os = (length(vDates_is) + 1L):(length(vDates_is) + iH)
     }
 
     vDateFull = c(vDates_is, vDates_os)
 
-    if (iK <= 5) {
-        layout(matrix(1:iK, iK, 1), heights = c(rep(2, iK - 1), 2.5))
-        for (i in 1:(iK)) {
-            if (i == 1)
+    if (iK <= 5L) {
+        layout(matrix(1:iK, iK, 1L), heights = c(rep(2, iK - 1), 2.5))
+        for (i in 1L:(iK)) {
+            if (i == 1L)
                 par(mar = c(0, 4, 0.1, 2))
-            if (i != 1 & i != iK)
+            if (i != 1L & i != iK)
                 par(mar = c(0, 4, 0, 2))
             if (i == iK)
                 par(mar = c(3, 4, 0, 2))
 
             vLim = c(min(cBands[, , i], mTheta_is[, i]), max(cBands[, , i], mTheta_is[, i]))
 
-            plot(vDateFull, rep(0, length(vDateFull)), type = "n", xaxt = "n", xlab = "", ylab = "",
-                las = 1, ylim = vLim)
+            plot(vDateFull, rep(0L, length(vDateFull)), type = "n", xaxt = "n", xlab = "", ylab = "",
+                las = 1L, ylim = vLim)
             grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
 
             lines(vDates_is, mTheta_is[, i])
@@ -516,44 +516,44 @@ PlotMultipleSeries_Bands_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os
             for (q in 1:iQ) {
               lines(vDates_os, cBands[, q, i], col = "blue")
             }
-            abline(v = tail(vDates_is, 1), lty = 2)
-            axis(4, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = F, padj = -1)
+            abline(v = tail(vDates_is, 1L), lty = 2L)
+            axis(4L, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = FALSE, padj = -1)
         }
         if (!is(vDateFull, "integer")) {
-            axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2] - vDateFull[1]))
-            axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2] - vDateFull[1])),
+            axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2L] - vDateFull[1L]))
+            axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2L] - vDateFull[1L])),
                 labels = FALSE, tcl = -0.2)
         } else {
-            foo = vDateFull[c(1, seq(0, iH + iS, ceiling((iH + iS)/20))[-1])]
-            axis(1, at = foo, labels = foo)
+            foo = vDateFull[c(1L, seq(0L, iH + iS, ceiling((iH + iS)/20))[-1L])]
+            axis(1L, at = foo, labels = foo)
         }
     } else {
         nPlot = ceiling(iK/10)
-        plotSeq = seq(1, iK + 1, 5)
-        Start = 1
+        plotSeq = seq(1L, iK + 1L, 5L)
+        Start = 1L
         PlotType2 = ""
 
         for (j in 1:nPlot) {
             if (PlotType2 != "0") {
 
-                layout(matrix(1:10, 5, 2), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
+                layout(matrix(1:10, 5L, 2L), heights = c(rep(2, 4), 2.5, rep(2, 4), 2.5))
 
-                for (i in Start:(Start + 9)) {
+                for (i in Start:(Start + 9L)) {
                   if (i <= iK) {
                     if (any(i == plotSeq)) {
                       par(mar = c(0, 4, 0.1, 2))
                     }
-                    if (all(i != plotSeq) & all(i != plotSeq - 1)) {
+                    if (all(i != plotSeq) & all(i != plotSeq - 1L)) {
                       par(mar = c(0, 4, 0, 2))
                     }
-                    if (any(i == plotSeq - 1)) {
+                    if (any(i == plotSeq - 1L)) {
                       par(mar = c(3, 4, 0, 2))
                     }
 
                     vLim = c(min(cBands[, , i], mTheta_is[, i]), max(cBands[, , i], mTheta_is[, i]))
 
                     plot(vDateFull, rep(0, length(vDateFull)), type = "n", xaxt = "n", xlab = "", ylab = "",
-                      las = 1, ylim = vLim)
+                      las = 1L, ylim = vLim)
                     grid(nx = 10, ny = 10, col = "gray", lty = "dotted")
 
                     lines(vDates_is, mTheta_is[, i])
@@ -563,24 +563,24 @@ PlotMultipleSeries_Bands_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os
                       lines(vDates_os, cBands[, q, i], col = "blue")
                     }
 
-                    abline(v = tail(vDates_is, 1), lty = 2)
-                    axis(4, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = F, padj = -1)
+                    abline(v = tail(vDates_is, 1L), lty = 2L)
+                    axis(4L, at = mean(vLim), labels = colnames(mTheta_is)[i], tick = FALSE, padj = -1L)
 
-                    if (any(i == plotSeq - 1) | (i == iK)) {
+                    if (any(i == plotSeq - 1L) | (i == iK)) {
 
                       if (!is(vDateFull, "integer")) {
-                        axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2] - vDateFull[1]))
-                        axis.Date(1, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2] -
-                          vDateFull[1])), labels = FALSE, tcl = -0.2)
+                        axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = vDateFull[2L] - vDateFull[1L]))
+                        axis.Date(1L, at = seq(min(vDateFull), max(vDateFull), by = 0.25 * (vDateFull[2L] -
+                          vDateFull[1L])), labels = FALSE, tcl = -0.2)
                       } else {
-                        foo = vDateFull[c(1, seq(0, (iH + iS), ceiling((iH + iS)/20))[-1])]
-                        axis(1, at = foo, labels = foo)
+                        foo = vDateFull[c(1L, seq(0L, (iH + iS), ceiling((iH + iS)/20))[-1L])]
+                        axis(1L, at = foo, labels = foo)
                       }
 
                     }
                   }
                 }
-                Start = Start + 10
+                Start = Start + 10L
                 if (j < nPlot)
                   PlotType2 = readline("Print enter for next figures or 0 to exit\n:")
 
@@ -593,7 +593,7 @@ PlotMultipleSeries_Bands_wis <- function(mTheta_is, mTheta_os, iK, iH, vDates_os
 
 PlotPit <- function(vU, BIN) {
 
-    layout(matrix(1:1, 1, 1), heights = c(4))
+    layout(matrix(1, 1L, 1L), heights = c(4))
     par(mar = c(3, 4, 0.1, 2))
 
     h = BIN$hist
@@ -601,22 +601,22 @@ PlotPit <- function(vU, BIN) {
     confidence = BIN$confidence
 
     plot(h, col = "blue", ylim = c(0, max(confidence * 1.2, n_i * 1.2)))
-    abline(h = confidence, col = "red", lwd = 2, xlim = c(0, 1))
+    abline(h = confidence, col = "red", lwd = 2L, xlim = c(0, 1))
 }
 
 PlotCovariances <- function(cCov, iN, iT, vDates, vNames) {
 
-    iL = iN * (iN + 1)/2
+    iL = iN * (iN + 1L)/2L
 
     vNamesFull = character(iL)
     mCov = matrix(0, iT, iL)
 
-    iC = 1
+    iC = 1L
     for (i in 1:iN) {
         for (j in 1:i) {
             vNamesFull[iC] = paste(vNames[i], vNames[j], sep = "-")
             mCov[, iC] = cCov[i, j, ]
-            iC = iC + 1
+            iC = iC + 1L
         }
     }
 
